# -*- coding: utf-8 -*-

import os
import sys

from codecs import open
from setuptools import setup, find_packages
from setuptools.command.test import test as TestCommand

here = os.path.abspath(os.path.dirname(__file__))

class PyTest(TestCommand):
	user_options = [('pytest-args=', 'a', "Arguments to pass into py.test")]

	def initialize_options(self):
		TestCommand.initialize_options(self)
		try:
			from multiprocessing import cpu_count
			self.pytest_args = ['-n', str(cpu_count()), '--boxed']
		except (ImportError, NotImplementedError):
			self.pytest_args = ['-n', '1', '--boxed']

	def finalize_options(self):
		TestCommand.finalize_options(self)
		self.test_args = []
		self.test_suite = True

	def run_tests(self):
		import pytest

		errno = pytest.main(self.pytest_args)
		sys.exit(errno)


# 'setup.py publish' shortcut.
if sys.argv[-1] == 'publish':
	os.system('python setup.py sdist bdist_wheel')
	os.system('twine upload dist/*')
	sys.exit()

requires = [
	'certifi>=2018.1.18',
	'futures>=3.2.0',
	'paho-mqtt>=1.3.1',
	'pycrypto>=.6.1',
	'python-dateutil>=2.6.1',
]

test_requirements = ['pytest-cov', 'pytest-mock', 'pytest-xdist', 'pytest>=2.8.0']

about = {}
# 'aliyun-python-sdk-iot-client',
with open(os.path.join(here, 'aliyunsdkiotclient', '__version__.py'), 'r', 'utf-8') as f:
	exec (f.read(), about)

with open('README.md', 'r', 'utf-8') as f:
	readme = f.read()
with open('HISTORY.rst', 'r', 'utf-8') as f:
	history = f.read()

setup(
	name=about['__title__'],
	version=about['__version__'],
	description=about['__description__'],
	long_description=readme + '\n\n' + history,
	author=about['__author__'],
	author_email=about['__author_email__'],
	url=about['__url__'],
	packages=find_packages(exclude=["tests*"]),
	package_data={'': ['LICENSE', 'NOTICE'], 'aliyun-python-sdk-iot-client': ['*.pem']},
	include_package_data=True,
	python_requires=">=2.6, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*",
	install_requires=requires,
	license=about['__license__'],
	zip_safe=False,
	classifiers=(
		'Intended Audience :: Developers',
		'Natural Language :: English',
		'License :: OSI Approved :: Apache Software License',
		'Programming Language :: Python',
		'Programming Language :: Python :: 2',
		'Programming Language :: Python :: 2.6',
		'Programming Language :: Python :: 2.7',
		'Programming Language :: Python :: 3',
		'Programming Language :: Python :: 3.4',
		'Programming Language :: Python :: 3.5',
		'Programming Language :: Python :: 3.6',
		'Programming Language :: Python :: Implementation :: CPython',
		'Programming Language :: Python :: Implementation :: PyPy'
	),
	cmdclass={'test': PyTest},
	tests_require=test_requirements,
)
